.. _misc-label:

misc
====

General utility routines, especially simple GUI dialogs for different
applications 

Functions
---------

* :func:`misc.get_file` ... GUI-dialog for file-selection
* :func:`misc.get_dir` ... GUI-dialog for directory-selection
* :func:`misc.get_screensize` ... get width and height of current display [in pixels]
* :func:`misc.progressbar` ... console-based progressbar, to indicate the level of completeness
* :func:`misc.save_file` ... GUI-dialog for saving file

.. toctree::
   :maxdepth: 2

Details
-------
.. automodule:: misc
    :members:
